#!/bin/sh
# The next line is executed by /bin/sh, but not tcl \
  exec wish8.4 "$0" ${1+"$@"}

#############################################################################
#############################################################################
## This script implements only drop targets, that utilise our cross-platform
## formats Text, Files, Image. This is a simple demo showing the ability to
## understand a wide range of Windows platform specific formats...
##
## Georgios Petasis, 03/01/2000
#############################################################################
#############################################################################

## Check Tk version:
package require Tk 8.3

if {$::tcl_version == "8.3" && ![package vsatisfies $::tcl_patchLevel 8.3.3]} {
    tk_messageBox -type ok -icon error \
	    -message "  =====> TkDND requires at least tk8.3.3! <====="
    exit 1
}

if {[string equal $tcl_platform(platform) unix]} {
  option add *font {arial 12}
}

## Load tkdnd package...
lappend auto_path ../lib
package require tkdnd
catch {package require Img}

##
## Create our main window...
##
wm overrideredirect . 1
wm geometry . 1x1-10-10
set win .demo_window
toplevel $win
wm title $win "Simple Drop Demo..."
bind $win <Destroy> {exit}

## Add drag sources...
set dwin $win.drag_sources
frame $dwin
label $dwin.cf_text  -bg red -fg white -relief raised -bd 1 -text CF_TEXT
label $dwin.cf_otext -bg red -fg white -relief raised -bd 1 -text CF_OEMTEXT
label $dwin.cf_utext -bg red -fg white -relief raised -bd 1 -text CF_UNICODETEXT

label $dwin.files  -bg green -fg black -relief raised -bd 1 -text CF_HDROP

label $dwin.images -bg green -fg black -relief raised -bd 1 -text CF_DIB

grid $dwin.cf_text  -padx 2 -pady 2 -sticky snew
grid $dwin.cf_otext -padx 2 -pady 2 -sticky snew
grid $dwin.cf_utext -padx 2 -pady 2 -sticky snew
grid $dwin.files    -padx 2 -pady 2 -sticky snew
grid $dwin.images   -padx 2 -pady 2 -sticky snew

## Add drop targets...
label  $win.text  -height 3 -bg red    -text {Drop any textual format here!}
label  $win.files -height 3 -bg green  -text {Drop any file(s) here!}
label  $win.image -height 3 -bg yellow -text {Drop any image format here!}
canvas $win.dropped_data -bg white -relief sunken -bd 2
$win.dropped_data create text  150 150 -tags {text}  -width 500 -justify left
$win.dropped_data create image 150 150 -tags {image} -anchor n

## Pack widgets...
grid $win.drag_sources -row 0 -column 0 -sticky new  -padx 2 -pady 4 -rowspan 4
grid $win.text         -row 0 -column 1 -sticky snew -padx 2 -pady 4
grid $win.files        -row 1 -column 1 -sticky snew -padx 2 -pady 4
grid $win.image        -row 2 -column 1 -sticky snew -padx 2 -pady 4
grid $win.dropped_data -row 3 -column 1 -sticky snew -padx 2 -pady 4
grid rowconfigure    $win 3 -weight 1
grid columnconfigure $win 0 -weight 1
grid columnconfigure $win 1 -weight 1

## Register our drop targets. Do not forget that widgets must have been
## created in order to be drag&drop aware :-)
update idletasks
dnd bindtarget $win.text  Text  <Drop> {HandleTextDrop  %D %T}
dnd bindtarget $win.files Files <Drop> {HandleFileDrop  %D %T}
dnd bindtarget $win.image Image <Drop> {HandleImageDrop %D %T}

## Register our drag sources...
dnd bindsource $dwin.cf_text  CF_TEXT \
  {return "CF_TEXT: Greek: \u03b1\u03b2\u03ac\u03c1\u03b5\u03c4\u03bf\u03c2"}
dnd bindsource $dwin.cf_otext CF_OEMTEXT \
  {return "CF_OEMTEXT: Greek: \u03b1\u03b2\u03ac\u03c1\u03b5\u03c4\u03bf\u03c2"}
dnd bindsource $dwin.cf_utext CF_UNICODETEXT \
  {return "CF_UNICODETEXT: Greek: \u03b1\u03b2\u03ac\u03c1\u03b5\u03c4\u03bf\u03c2"}
dnd bindsource $dwin.files    CF_HDROP       {return [pwd]}
dnd bindsource $dwin.images   CF_DIB         {return itk}
foreach widget {cf_text cf_otext cf_utext files} {
  bind $dwin.$widget <1> {dnd drag %W}
}

proc HandleTextDrop {data type} {
  global win
  
  $win.dropped_data itemconfigure image -image {}
  $win.dropped_data itemconfigure text  -text $data
  $win.dropped_data configure -scrollregion [$win.dropped_data bbox all]
}

proc HandleFileDrop {data type} {
  global win
  
  $win.dropped_data itemconfigure image -image {}
  $win.dropped_data itemconfigure text  -text $data
  $win.dropped_data configure -scrollregion [$win.dropped_data bbox all]
}

proc HandleImageDrop {data type} {
  global win

  $win.dropped_data itemconfigure text  -text [string length $data]
  if {[catch {image create photo dropped_image -data $data -format bmp} er]} {
    $win.dropped_data itemconfigure text  -text $er
    image create photo dropped_image
  }
  $win.dropped_data itemconfigure image -image dropped_image
  $win.dropped_data itemconfigure text  -text {}
  $win.dropped_data configure -scrollregion [$win.dropped_data bbox all]
}

#############################################################################
## What follows is a sample tk image (tk logo :-))

image create photo itk -data {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====}
